@@ -125,7 +125,6 @@ func impersonateRBAC(t *testing.T, sa, namespace string, kubeClient kubernetes.I
 
 func TestEventListenerCreate(t *testing.T) {
 	c, namespace := setup(t)
-	t.Parallel()
 	defer cleanup(t, c, namespace, "my-eventlistener")
 	knativetest.CleanupOnInterrupt(func() { cleanup(t, c, namespace, "my-eventlistener") }, t.Logf)
 
@@ -243,7 +242,7 @@ func TestEventListenerCreate(t *testing.T) {
 			ObjectMeta: metav1.ObjectMeta{Name: "my-role"},
 			Rules: []rbacv1.PolicyRule{{
 				APIGroups: []string{triggersv1.GroupName},
-				Resources: []string{"clustertriggerbindings", "eventlisteners", "triggerbindings", "triggertemplates", "triggers"},
+				Resources: []string{"clustertriggerbindings", "eventlisteners", "clusterinterceptors", "triggerbindings", "triggertemplates", "triggers"},
 				Verbs:     []string{"get", "list", "watch"},
 			}, {
 				APIGroups: []string{"tekton.dev"},
@@ -298,14 +297,16 @@ func TestEventListenerCreate(t *testing.T) {
 					Ref: ptr.String(tt.Name),
 				},
 				Interceptors: []*triggersv1.EventInterceptor{{
-					CEL: &triggersv1.CELInterceptor{
-						Filter: `body.action == "edited"`,
-					},
+					Ref: triggersv1.InterceptorRef{Name: "cel"},
+					Params: []triggersv1.InterceptorParams{{
+						Name:  "filter",
+						Value: ToV1JSON(t, `body.action == "edited"`),
+					}},
 				}},
 			}},
-			Replicas: ptr.Int32(3),
 			Resources: triggersv1.Resources{
 				KubernetesResource: &triggersv1.KubernetesResource{
+					Replicas: ptr.Int32(3),
 					WithPodSpec: duckv1.WithPodSpec{
 						Template: duckv1.PodSpecable{
 							Spec: corev1.PodSpec{
@@ -449,8 +450,9 @@ func TestEventListenerCreate(t *testing.T) {
 		t.Errorf("sink did not return 2xx response. Got status code: %d", resp.StatusCode)
 	}
 	wantBody := sink.Response{
-		EventListener: "my-eventlistener",
-		Namespace:     namespace,
+		EventListener:    "my-eventlistener",
+		Namespace:        namespace,
+		EventListenerUID: string(el.GetUID()),
 	}
 	var gotBody sink.Response
 	if err := json.NewDecoder(resp.Body).Decode(&gotBody); err != nil {
